#!/usr/local/bin/python
# coding: UTF-8
from distutils.core import setup
setup(name='supermathaaabbb',
      version='1.0',
      description='这是本公司对外发布的测试模块',
      author='zwl123456789',
      author_email='zhaowanli@mails.ccnu.edu.cn ',
      py_modules=['supermath.a1model','supermath.a2model']
      )